from emod_api import schema_to_class as s2c
import emod_api.interventions.common as common
import emod_api.interventions.utils as utils
from emodpy_tbhiv.interventions import purge_campaign_event

co_event = "TbDrugDistributed"

def TBDrugTreatment(
        camp,
        trigger_treatment_list,
        drug_name= 'DOTS',
        inactivation_rate=0,
        mortality_rate=0,
        clearance_rate=0,
        resistance_rate=0,
        relapse_rate=0,
        reduced_transmit=1.0,
        start_day=0,
        treatment_duration=180,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='TBDrugTreatment'):
    """
    TBDrugTreatment
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path
    act_intervention = s2c.get_class_with_defaults( "AntiTBDrug", schema_path ) 

    # Third, do the actual settings
    act_intervention.Drug_Type = drug_name
    act_intervention.TB_Drug_Inactivation_Rate = inactivation_rate
    #intervention.TB_Drug_Clearance_Rate = clearance_rate
    act_intervention.TB_Drug_Resistance_Rate = resistance_rate
    act_intervention.TB_Drug_Relapse_Rate = relapse_rate
    act_intervention.TB_Drug_Mortality_Rate = mortality_rate
    act_intervention.Reduced_Transmit = reduced_transmit
    act_intervention.Durability_Profile = 'FIXED_DURATION_CONSTANT_EFFECT'
    act_intervention.Primary_Decay_Time_Constant = treatment_duration

    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent", schema_path )
    bcast_intervention.Broadcast_Event = camp.get_send_trigger( co_event )

    event = common.TriggeredCampaignEvent( camp, start_day,event_name, trigger_treatment_list, [ act_intervention, bcast_intervention ], Nodeset_Config=utils.do_nodes( camp.schema_path, nodeIDs ), Duration=duration, Property_Restrictions=property_restrictions_list )
    purge_campaign_event( event )

    return event

def new_intervention_as_file( camp, filename=None ):
    camp.add( TBDrugTreatment( camp, trigger_treatment_list=[ "Births" ], drug_name="DOTS" ) )
    if filename is None:
        filename = "tb_drug_treat.json"
    camp.save( filename )
    return filename

