from emod_api import schema_to_class as s2c
import emod_api.interventions.common as common
import emod_api.interventions.utils as utils
from emodpy_tbhiv.interventions import purge_campaign_event

def TPVC(
        camp,
        trigger_treatment_list,
        property_to_change,
        final_prop_value,
        revert=0,
        daily_prob=1, 
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='PropertyValueChanger'):
    """
    Triggered Property Value Changer
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path
    intervention = s2c.get_class_with_defaults( "PropertyValueChanger", schema_path )

    # Third, do the actual settings
    intervention.Target_Property_Key = property_to_change
    intervention.Target_Property_Value = final_prop_value
    intervention.Daily_Probability = daily_prob
    intervention.Maximum_Duration = -1
    intervention.Revert = revert

    event = common.TriggeredCampaignEvent( camp, start_day,event_name, trigger_treatment_list, [ intervention ], Nodeset_Config=utils.do_nodes( camp.schema_path, nodeIDs ), Duration=duration, Property_Restrictions=property_restrictions_list )
    purge_campaign_event( event )

    return event

def new_intervention_as_file( camp, filename="tpvc.json" ):
    camp.add( TPVC( camp, trigger_treatment_list=["Births"], property_to_change="Risk", final_prop_value="High" ) )
    camp.save( filename )
    return filename

